@@ -10,7 +10,11 @@ def execute(args):
 
     for path in args.paths:
         filename, extension = os.path.splitext(path)
-        new_path = '%s.%s' % (filename, args.to_format, )
+        new_path = '%s%s.%s' % (
+            filename,
+            args.suffix,
+            args.to_format,
+        )
         convert(path, new_path,
             resize=args.resize,
             quality=args.quality,
